// @ts-nocheck
import { useCallback } from 'react'
import { SiGithub } from 'react-icons/si'
import styled from 'styled-components'
import Button from './Button'
import Backdrop from './Backdrop'

const backdropStyle = {
  borderBottomLeftRadius: '50% 25%',
  borderBottomRightRadius: '50% 25%',
}

export default function Banner () {
  const onMoveDocPage = useCallback(() => {
    window.location.href = 'https://swlab.bwg.co.kr/docs'
  }, [])

  return (
    <Wrapper>
      <Backdrop style={backdropStyle} />
      <Overlay>
        <BannerTitle type='main' fontSize='5em'>Bankware Global</BannerTitle>
        <BannerTitle type='sub' fontSize='3.5em'>Software Lab.</BannerTitle>
        <BannerDesc>Analyzing new technologies and ideas • Developing innovative products and services</BannerDesc>
        <ButtonGroup>
          <Button onClick={onMoveDocPage} text='Documetation' />
          <Button text='GitHub' icon={<SiGithub />}/>
        </ButtonGroup>
      </Overlay>
    </Wrapper>
  )
}

const Wrapper = styled.div`
    position: relative;
    width: 100%;
    height: 610px;
    background-color: #12071f;
    border-bottom-left-radius: 50% 25%;
    border-bottom-right-radius: 50% 25%;
`
const Overlay = styled.div`
    position: absolute;
    top: 60%;
    left: 50%;
    transform: translate3d(-50%, -50%, 0);
    text-align: center;
`
const BannerTitle = styled.h1`
    margin: 0;
    padding: 0;
    font-size: ${(props) => props.fontSize};
    font-weight: 600;
    letter-spacing: -0.05em;
    background: ${(props) => (props.type === 'main' ? 'linear-gradient(30deg, #0072CE, #fff)' : '#fff')};
    background-clip: text;
    -webkit-text-fill-color: transparent;
`
const BannerDesc = styled.h3`
  font-size: 1.5em;
  font-weight: 400;
  margin-top: 15px;
  color: #fff;
`
const ButtonGroup = styled.div`
  display: flex;
  margin-top: 15px;
  width: 100%;
  justify-content: center;
`
