// @ts-nocheck
import { useCallback } from 'react'
import styled from 'styled-components'
import Backdrop from './Backdrop'
import Button from './Button'

export default function Card (props) {
  const { title, subTitle, mainDesc, subDesc } = props

  const onMovePage = useCallback((product) => () => {
    window.location.href = `https://swlab.bwg.co.kr/docs/${product}`
  }, [])

  return <Scene>
    <FlipCard>
      <CardFace className='front'>
        <Title size='50px' fontWeight={700} align='left'>{title}</Title>
        <Title size='18px' fontWeight={500} align='left'>{subTitle}</Title>
        <div style={{ width: '100%', border: '1px solid #0072ce', marginTop: '10px' }}></div>
        <div style={{ height: '110px' }}></div>
        <Title size='25px' fontWeight={700} color='#12071F' align='center'>{mainDesc}</Title>
      </CardFace>
      <CardFace className='back'>
        <Backdrop />
        <Overlay>
          <div style={{ flexGrow: '1' }}>
            {
              subDesc && subDesc.map((desc, idx) => <Title key={idx} className='mb_10' size='14px' fontWeight={700} align='center'>
                {desc}
              </Title>)
            }
          </div>
          <Button onClick={onMovePage(title.toLowerCase())} text='Learn more'/>
        </Overlay>
      </CardFace>
    </FlipCard>
  </Scene>
}

const Scene = styled.div`
  position: 'relative';
  /* width: 400px; */
  width: 100%;
  height: 450px;
  margin-top: 40px;
  perspective: 1200px;
`
const FlipCard = styled.article`
  width: 100%;
  height: 100%;
  transition: transform 1s;
  transform-style: preserve-3d;
  cursor: pointer;
  position: relative;

  ${Scene}:hover & {
    transform: rotateY(180deg);
  }
`
const CardFace = styled.article`
  position: absolute;
  width: 100%;
  height: 100%;
  padding: 1.5rem;
  color: white;
  text-align: center;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  border: 1px solid hsla(0, 0%, 9%, .04);
  border-radius: 16px;
  box-shadow: 0 2px 8px -2px hsla(0, 0%, 9%, .08), 0 8px 12px -2px hsla(0, 0%, 9%, .16);

    &.front {
      background-color: #fff;
      color: #0072ce;
    }
    &.back {
      background-color: #12071f;
      color: white;
      transform: rotateY(180deg);
    }
`
const Title = styled.h1`
    font-size: ${props => props.size};
    font-weight: ${props => props.fontWeight};
    text-align: ${props => props.align};
    color: ${props => props.color};
`
const Overlay = styled.div`
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: center;
    padding: 3rem;
`
